@@ -6,7 +6,7 @@ var stealthyRequire = require('stealthy-require');
 // It has no side-effects like patching the module loader or anything.
  
 // Any regular require works as always.
-var request1 = require('request');
+var request1 = require('got');
  
 // 2. Call stealthyRequire with passing the require cache and a callback.
 var requestFresh = stealthyRequire(require.cache, function () {
@@ -15,7 +15,7 @@ var requestFresh = stealthyRequire(require.cache, function () {
  
     // 2b. Any require taking place here takes place on a clean require cache.
     // Since the require call is part of the user's code it also works with module bundlers.
-    return require('request');
+    return require('got');
     // Anything returned here will be returned by stealthyRequire(...).
  
     // 2c. After this callback gets called the require cache is
@@ -26,7 +26,7 @@ var requestFresh = stealthyRequire(require.cache, function () {
  
 // Any regular require again works as always.
 // In this case require returns the cached request module instance.
-var request2 = require('request');
+var request2 = require('got');
  
 // And voilà:
 
